@@ -1,5 +1,5 @@
 package UNIVERSAL::require;
-$UNIVERSAL::require::VERSION = '0.15_01';
+$UNIVERSAL::require::VERSION = '0.12';
 
 # We do this because UNIVERSAL.pm uses CORE::require().  We're going
 # to put our own require() into UNIVERSAL and that makes an ambiguity.
@@ -8,9 +8,7 @@ BEGIN { require UNIVERSAL }
 
 package UNIVERSAL;
 
-use 5.006;
 use strict;
-use warnings;
 
 use vars qw($Level);
 $Level = 0;
@@ -88,8 +86,7 @@ sub require {
 
     # For performance reasons, check if its already been loaded.  This makes
     # things about 4 times faster.
-    # We use the eval { } to make sure $@ is not set. See RT #44444 for details
-    return eval { 1 } if $INC{$file};
+    return 1 if $INC{$file};
 
     my $return = eval qq{ 
 #line $call_line "$call_file"
@@ -97,7 +94,7 @@ CORE::require(\$file);
 };
 
     # Check for module load failure.
-    if( !$return ) {
+    if( $@ ) {
         $UNIVERSAL::require::ERROR = $@;
         return $return;
     }
@@ -107,12 +104,14 @@ CORE::require(\$file);
         eval qq{
 #line $call_line "$call_file"
 \$module->VERSION($want_version);
-1;
-}       or do {
+};
+
+        if( $@ ) {
             $UNIVERSAL::require::ERROR = $@;
             return 0;
-        };
+        }
     }
+
     return $return;
 }
 
@@ -148,11 +147,12 @@ sub use {
 package $call_package;
 #line $call_line "$call_file"
 \$module->import(\@imports);
-1;
-}   or do {
+};
+
+    if( $@ ) {
         $UNIVERSAL::require::ERROR = $@;
         return 0;
-    };
+    }
 
     return $return;
 }
@@ -183,7 +183,6 @@ See F<http://www.perl.com/perl/misc/Artistic.html>
 
 Michael G Schwern <schwern@pobox.com>
 
-Now maintained by Neil Bowers (NEILB).
 
 =head1 SEE ALSO
 
